@@ -4,7 +4,7 @@ $main::hilite{styl_js} = 0;
 
 $main::hilite{rexp_js} = [
 	'(\/{2}.*)',					{ color => 0xaaaaaa,},
-	'(var|new|for|function|if|else|return)',	{ color => 0x000000,	style => fs::Bold,},
+	'(\b(var|new|for|function|if|else|return)\b)',	{ color => 0x000000,	style => fs::Bold,},
 	'(Array)',							{ color => 0x00aa00,	style => fs::Bold,},
 	'(\"[^\"]*\")',					{ color => 0xdd0000,},
 	'(\'.*?\')',					{ color => 0xff00aa,},
@@ -13,4 +13,3 @@ $main::hilite{rexp_js} = [
 	'(\w+\.)',						{ color => 0x009900,},
 ];
 $main::hilite{blok_js} = [];
- 
\ No newline at end of file
